SlideSeq-class: The SlideSeq class

SlideSeq-classR Documentation

The SlideSeq class

Description

The SlideSeq class represents spatial information from the Slide-seq platform

Slots

coordinates

...

Slots

assay

Name of assay to associate image data with; will give this image priority for visualization when the assay is set as the active/default assay in a Seurat object

key

A one-length character vector with the object's key; keys must be one or more alphanumeric characters followed by an underscore “_” (regex pattern “^[a-zA-Z][a-zA-Z0-9]*_$”)

misc

A named list of unstructured miscellaneous data


Seurat documentation built on June 26, 2026, 5:08 p.m.