getThreads: Get the number of threads being used for parallel processing...

View source: R/utilities.R

getThreadsR Documentation

Get the number of threads being used for parallel processing in Seurat

Description

Get the number of threads being used for parallel processing in Seurat

Usage

getThreads(verbose = TRUE)

Arguments

verbose

Whether to print the number of threads set and available cores to the console

Value

The number of threads currently set for processing


Seurat documentation built on Oct. 3, 2026, 5:06 p.m.