View source: R/visualization.R
| ElbowPlot | R Documentation |
Plots per-component standard deviations (or approximate singular values if running PCAFast), percent variance explained per principal component, or cumulative percent variance explained, to help pick an elbow in the graph. This elbow often corresponds well with significant dimensions and is much faster to run than Jackstraw.
ElbowPlot(
object,
ndims = 20,
reduction = "pca",
plot_type = c("stdev", "variance", "cumulative_variance")
)
object |
Seurat object |
ndims |
Number of dimensions to plot (positive integer; capped by stored components) |
reduction |
Reduction technique to plot (default is 'pca') |
plot_type |
One of |
A ggplot object
data("pbmc_small")
ElbowPlot(object = pbmc_small)
ElbowPlot(object = pbmc_small, plot_type = "variance")
ElbowPlot(object = pbmc_small, plot_type = "cumulative_variance")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.