| getThreads | R Documentation |
Get the number of threads being used for parallel processing in Seurat
getThreads(verbose = TRUE)
verbose |
Whether to print the number of threads set and available cores to the console |
The number of threads currently set for processing
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.